"use strict";
/**
 * @packageDocumentation
 * @module array
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultSort = exports.binarySearcher = void 0;
/**
 * Binary searcher method
 * @param searchValue
 * @param searchArray
 * @private
 * @internal
 */
function binarySearcher(searchValue, searchArray, property) {
    let first = 0; //left endpoint
    let last = searchArray.length - 1; //right endpoint
    let position = -1;
    let found = false;
    let middle;
    while (!found && first <= last) {
        middle = Math.floor((first + last) / 2);
        const checkValue = property ? searchArray[middle][property] : searchArray[middle];
        if (checkValue == searchValue) {
            found = true;
            position = middle;
        }
        else if (checkValue > searchValue) {
            //if in lower half
            last = middle - 1;
        }
        else {
            //in in upper half
            first = middle + 1;
        }
    }
    return position;
}
exports.binarySearcher = binarySearcher;
/**
 * Default sort method that provides a number value of comparison order
 * @private
 * @param first The first comparison parameter
 * @param second The second comparison parameter
 *
 * @returns Number related to the sort order of two comparison parameters
 */
function defaultSort(first, second) {
    if (typeof first === 'string') {
        return first.localeCompare(second);
    }
    if (first === second)
        return 0;
    return first < second ? -1 : 1;
}
exports.defaultSort = defaultSort;
//# sourceMappingURL=binary-search.js.map