/**
 * @packageDocumentation
 * @module array
 */
import { InputModifierFn, PredicateFn } from '../types/array-compare';
/**
 * Filter an array to find intersecting items with optional predicate method, otherwise
 * uses simple comparison
 * @param input The input array of values to check against the source
 * @param predicate Optional method for comparison
 *
 * @returns Function that is used with RxJS map method
 * @private
 * @internal
 */
export declare function mapIntersectsWith<T>(input: T[], predicate?: PredicateFn<T>): (value: T[]) => T[];
/**
 * Return a method that's used to check that two arrays have intersecting members,
 * takes an optional method that allows methods to be mutated
 *
 * @param checkArray
 * @param mutate
 * @private
 * @internal
 */
export declare function mapIntersection<T, K>(checkArray: T[], mutate?: InputModifierFn<T, T | K>): (value: T[]) => T[];
